# GW Low-latency Test Suite

## Features

The gw-lts software provides:

* real-time end-to-end consistency checks of science outputs from gravitational wave searches
* capability to simulate gravitational wave search outputs with a fake data set
* ability to display results with an example Grafana dashboard template

## Installation

WRITEME

## Usage

WRITEME

